@@ -11,7 +11,7 @@ use Carp();
 use English qw( -no_match_vars );
 use DirHandle();
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -115,9 +115,11 @@ sub _timezones {
     my $path = File::Spec->catfile( $self->directory(), 'zone.tab' );
     my $handle = FileHandle->new($path)
       or Carp::croak("Failed to open $path for reading:$EXTENDED_OS_ERROR");
-    my $_last_modified = ( stat _ )[ _STAT_MTIME_IDX() ];
+    my @stat = stat $handle
+      or Carp::croak("Failed to stat $path:$EXTENDED_OS_ERROR");
+    my $last_modified = $stat[ _STAT_MTIME_IDX() ];
     if (   ( $self->{_timezone_cache} )
-        && ( $self->{_timezone_cache} == $_last_modified ) )
+        && ( $self->{_timezone_cache} == $last_modified ) )
     {
     }
     else {
@@ -133,6 +135,7 @@ sub _timezones {
         }
         close $handle
           or Carp::croak("Failed to close $path:$EXTENDED_OS_ERROR");
+        $self->{_timezone_cache} = $last_modified;
     }
     my @sorted_zones = sort { $a cmp $b } @{ $self->{_zones} };
     return @sorted_zones;
@@ -191,6 +194,16 @@ sub comment {
     }
 }
 
+sub area {
+    my ($self) = @_;
+    return $self->{area};
+}
+
+sub location {
+    my ($self) = @_;
+    return $self->{location};
+}
+
 sub timezone {
     my ( $self, $new ) = @_;
     my $old = $self->{tz};
@@ -201,6 +214,8 @@ sub timezone {
                 Carp::croak(
                     "'$new' does not have a valid format for a TZ timezone");
             }
+            $self->{area}     = $LAST_PAREN_MATCH{area};
+            $self->{location} = $LAST_PAREN_MATCH{location};
             my $path = File::Spec->catfile( $self->directory(), $new );
             if ( !-f $path ) {
                 Carp::croak(
@@ -1377,9 +1392,11 @@ sub _read_tzfile {
     my $path = File::Spec->catfile( $self->directory, $tz );
     my $handle = FileHandle->new($path)
       or Carp::croak("Failed to open $path for reading:$EXTENDED_OS_ERROR");
-    my $_last_modified = ( stat _ )[ _STAT_MTIME_IDX() ];
+    my @stat = stat $handle
+      or Carp::croak("Failed to stat $path:$EXTENDED_OS_ERROR");
+    my $last_modified = $stat[ _STAT_MTIME_IDX() ];
     if (   ( $self->{_tzdata}->{$tz}->{mtime} )
-        && ( $self->{_tzdata}->{$tz}->{mtime} == $_last_modified ) )
+        && ( $self->{_tzdata}->{$tz}->{mtime} == $last_modified ) )
     {
     }
     else {
@@ -1387,7 +1404,7 @@ sub _read_tzfile {
         my $header = $self->_read_header( $handle, $path );
         $self->_read_v1_tzfile( $handle, $path, $header, $tz );
         $self->_read_v2_tzfile( $handle, $path, $header, $tz );
-        $self->{_tzdata}->{$tz}->{mtime} = $_last_modified;
+        $self->{_tzdata}->{$tz}->{mtime} = $last_modified;
     }
     close $handle
       or Carp::croak("Failed to close $path:$EXTENDED_OS_ERROR");
@@ -1422,7 +1439,7 @@ Version 0.01
 
 =head1 DESCRIPTION
 
-Time::Zone::Olson is intended to provide a simple but well tested interface to the Olson database that is available on most UNIX systems.  It provides an interface to list common time zones, such as Australia/Melbourne that are stored in the zone.tab file, and localtime/Time::Local::timelocal replacements to translate times to and from the users timezone, without changing the timezone used by Perl.  This allows logging/etc to be conducted in the system's local time.
+Time::Zone::Olson is intended to provide a simple interface to the Olson database that is available on most UNIX systems.  It provides an interface to list common time zones, such as Australia/Melbourne that are stored in the zone.tab file, and localtime/Time::Local::timelocal replacements to translate times to and from the users timezone, without changing the timezone used by Perl.  This allows logging/etc to be conducted in the system's local time.
 
 Time::Zone::Olson was designed to produce the same result as a 64bit copy of the L<date(1)|date(1)> command.
 
@@ -1454,6 +1471,14 @@ This object method can be used to get or set the root directory of the Olson dat
 
 This object method can be used to get or set the timezone, which will affect all future calls to L</local_time> or L</time_local>.  The parameter for this method should be in the Olson format of a timezone, such as C<"Australia/Melbourne">.
 
+=head2 area
+
+This object method will return the area component of the current timezone, such as Australia
+
+=head2 location
+
+This object method will return the location component of the current timezone, such as Melbourne
+
 =head2 local_time
 
 This object method has the same signature as the 64 bit version of the C<localtime> function.  That is, it accepts up to a 64 bit signed integer as the sole argument and returns the C<(seconds, minutes, hours, day, month, year, wday, yday, isdst)> definition for the timezone for the object.  The timezone used to calculate the local_time may be specified as a parameter to the L</new> method or via the L</timezone> method.
@@ -1502,6 +1527,10 @@ There has been a file system error while reading or closing the designated path
 
 There has been a file system error while opening the the designated path.  This could be permissions related, or the timezone in question doesn't exist?
 
+=item C<< Failed to stat %s:%s >>
+
+There has been a file system error while doing a L<stat|perlfunc/"stat"> the the designated path.  This could be permissions related, or the timezone in question doesn't exist?
+
 =item C<< Failed to read %s from %s:%s >>
 
 There has been a file system error while reading from the designated path.  The file could be corrupt?
